@@ -31,7 +31,7 @@ class Connect:
 
         if self.open_port(ipaddr, 8443) is False:
             raise Exception (f"Connection Error: {ipaddr}:8443 not reachable or open. Is this CUCM?")
-        if self.query("SELECT COUNT(*) FOM processnode") is False:
+        if self.query("SELECT COUNT(*) FROM processnode") is False:
             raise Exception (f"Connection Error: AXL request not valid. Improper credentials?")
 
         self.uds = UDS.Connect(ipaddr, username, passwd)
